@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -23,9 +23,8 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'default'         => 'Make the new stack the default stack'  ],
-        [ 'description|d=s' => 'Brief description of the stack'        ],
-        [ 'lock'            => 'Lock the new stack to prevent changes' ],
+        [ 'description|d=s' => 'Brief description of the stack' ],
+        [ 'dryrun'          => 'Do not commit any changes'      ],
     );
 
 
@@ -55,11 +54,11 @@ sub execute {
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -67,11 +66,11 @@ App::Pinto::Command::copy - create a new stack by copying another
 
 =head1 VERSION
 
-version 0.065_04
+version 0.041
 
 =head1 SYNOPSIS
 
-  pinto --root=REPOSITORY_ROOT copy [OPTIONS] FROM_STACK TO_STACK
+  pinto --root=REPOSITORY_ROOT stack copy [OPTIONS] FROM_STACK TO_STACK
 
 =head1 DESCRIPTION
 
@@ -79,43 +78,36 @@ This command creates a new stack by copying an existing one.  All the
 pins and properties from the existing stack will also be copied to the
 new one.  The new stack must not already exist.
 
-Use the L<new|App::Pinto::Command::new> command to create a new empty 
-stack, or the L<props|App::Pinto::Command::props> command to change 
-a stack's properties after it has been created.
+Please see the L<new|App::Pinto::Command::new> command to
+create a new empty stack, or the
+L<edit|App::Pinto::Command::edit> command to change a stack's
+properties after it has been created.
 
 =head1 COMMAND ARGUMENTS
 
 The two required arguments are the name of the source and target
-stacks.  Stack names must be alphanumeric plus hyphens and underscores,
-and are not case-sensitive.
+stacks.  Stack names must be alphanumeric (including "-" or "_") and
+will be forced to lowercase.
 
 =head1 COMMAND OPTIONS
 
 =over 4
 
-=item --default
+=item --description TEXT
 
-Also mark the new stack as the default stack.
+Annotates the new stack with a brief description of its purpose.
 
-=item --description=TEXT
+=item --dryrun
 
-=item -d TEXT
-
-Use TEXT for the description of the stack.  If not specified, defaults
-to 'Copy of stack FROM_STACK'.
-
-=item --lock
-
-Also lock the new stack to prevent future changes.  This is useful for
-creating a read-only "tag" of a stack.  You can always use the
-L<lock|App::Pinto::Command::lock> or
-L<unlock|App::Pinto::Command::unlock> commands at a later time.
+Go through all the motions, but do not actually commit any changes to
+the repository.  Use this option to see how operations would
+potentially impact the stack.
 
 =back
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -125,3 +117,7 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
