@@ -11,15 +11,16 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_02'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 #------------------------------------------------------------------------------
 
 sub opt_spec {
 
     return (
-        ['default'             => 'mark stack as the default'     ],
-        ['properties|props=s%' => 'name=value pairs of properties'],
+        ['default'              => 'mark stack as the default'     ],
+        [ 'dryrun'              => 'Do not commit any changes'     ],
+        ['properties|prop|P=s%' => 'name=value pairs of properties'],
     );
 }
 
@@ -36,21 +37,6 @@ sub validate_args {
 
 #------------------------------------------------------------------------------
 
-sub usage_desc {
-    my ($self) = @_;
-
-    my ($command) = $self->command_names();
-
-    my $usage =  <<"END_USAGE";
-%c --root=REPOSITORY_ROOT $command [OPTIONS] [STACK]
-END_USAGE
-
-    chomp $usage;
-    return $usage;
-}
-
-#------------------------------------------------------------------------------
-
 sub execute {
     my ($self, $opts, $args) = @_;
 
@@ -76,7 +62,7 @@ App::Pinto::Command::edit - change stack properties
 
 =head1 VERSION
 
-version 0.040_02
+version 0.041
 
 =head1 SYNOPSIS
 
@@ -108,9 +94,17 @@ index file for your repository.  DO NOT CHANGE THE DEFAULT STACK
 WITHOUT DUE DILLIGENCE.  It has broad impact, especially if your
 repository has multiple users.
 
+=item --dryrun
+
+Go through all the motions, but do not actually commit any changes to
+the repository.  Use this option to see how operations would
+potentially impact the stack.
+
 =item --properties name1=value1
 
-=item --props name1=value1
+=item --prop name1=value1
+
+=item -P name1=value1
 
 Specifies property names and values.  You can repeat this option to
 set multiple properties.  If the property with that name does not
