@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -19,9 +19,11 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'default'               => 'Make the new stack the default stack' ],
-        [ 'description|d=s'       => 'Brief description of the stack'       ],
+        [ 'description|d=s' => 'Brief description of the stack' ],
+        [ 'dryrun'          => 'Do not commit any changes'      ],
     );
+
+
 }
 
 #------------------------------------------------------------------------------
@@ -32,19 +34,28 @@ sub validate_args {
     $self->usage_error('Must specify exactly one stack')
         if @{$args} != 1;
 
-    $opts->{stack} = $args->[0];
-
     return 1;
 }
 
+#------------------------------------------------------------------------------
+
+sub execute {
+    my ($self, $opts, $args) = @_;
+
+    my $result = $self->pinto->run($self->action_name, %{$opts},
+                                                       stack => $args->[0]);
+
+    return $result->exit_status;
+}
+
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -52,7 +63,7 @@ App::Pinto::Command::new - create a new empty stack
 
 =head1 VERSION
 
-version 0.065_04
+version 0.041
 
 =head1 SYNOPSIS
 
@@ -62,35 +73,36 @@ version 0.065_04
 
 This command creates a new empty stack.
 
-See the L<copy|App::Pinto::Command::copy> command to create a new 
-stack from another one, or the L<props|App::Pinto::Command::props> 
-command to change a stack's properties after it has been created.
+Please see the L<copy|App::Pinto::Command::copy> command to
+create a new stack from another one, or the
+L<edit:App::Pinto::Command::copy> command to change a
+stack's properties after it has been created.
 
 =head1 COMMAND ARGUMENTS
 
 The required argument is the name of the stack you wish to create.
-Stack names must be alphanumeric plus hyphens and underscores, and
-are not case sensitive.
+Stack names must be alphanumeric (including "-" or "_") and will be
+forced to lowercase.
 
 =head1 COMMAND OPTIONS
 
 =over 4
 
-=item --default
+=item --description TEXT
 
-Also mark the new stack as the default stack.
+Annotates this stack with a description of its purpose.
 
-=item --description=TEXT
+=item --dryrun
 
-=item -d TEXT
-
-Use TEXT for the description of the stack.
+Go through all the motions, but do not actually commit any changes to
+the repository.  Use this option to see how operations would
+potentially impact the stack.
 
 =back
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -100,3 +112,8 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
+
