@@ -1,7 +1,7 @@
-# ABSTRACT: do nothing
-
 package App::Pinto::Command::nop;
 
+# ABSTRACT: initialize Pinto and exit
+
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -39,19 +39,19 @@ sub validate_args {
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
-App::Pinto::Command::nop - do nothing
+App::Pinto::Command::nop - initialize Pinto and exit
 
 =head1 VERSION
 
-version 0.065_04
+version 0.041
 
 =head1 SYNOPSIS
 
@@ -79,7 +79,7 @@ Sleep for N seconds before releasing the lock and exiting.  Default is 0.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -89,3 +89,7 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
