@@ -1,7 +1,7 @@
-# ABSTRACT: force a package to stay in a stack
-
 package App::Pinto::Command::pin;
 
+# ABSTRACT: force a package to stay in a stack
+
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -19,10 +19,8 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'dry-run'     => 'Do not commit any changes'           ],
-        [ 'message|m=s' => 'Message to describe the change'      ],
-        [ 'stack|s=s'   => 'Pin targets to this stack'           ],
-        [ 'use-default-message|M' => 'Use the generated message' ],
+        [ 'dryrun'      => 'Do not commit any changes'        ],
+        [ 'stack|s=s'   => 'Stack on which to pin the target' ],
     );
 }
 
@@ -38,11 +36,11 @@ sub args_from_stdin { return 1 }
 
 1;
 
-__END__
+
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -50,26 +48,25 @@ App::Pinto::Command::pin - force a package to stay in a stack
 
 =head1 VERSION
 
-version 0.065_04
+version 0.041
 
 =head1 SYNOPSIS
 
   pinto --root=REPOSITORY_ROOT pin [OPTIONS] TARGET ...
+  pinto --root=REPOSITORY_ROOT pin [OPTIONS] < LIST_OF_TARGETS
 
 =head1 DESCRIPTION
 
-This command pins a package so that it cannot be changed even if a
-different version is added or pulled to the stack The pin is local
-to the stack and does not affect any other stacks.
+This command pins a package so that it stays in the stack even if a
+newer version is subsequently mirrored, imported, or added to that
+stack.  The pin is local to the stack and does not affect any other
+stacks.
 
-A package must be registered on the stack before you can pin it.  To bring a
-package onto the stack, use the L<pull|App::Pinto::Command::pull> or 
-L<register|App::Pinto::Command::register> commands.  To remove the pin
-from a package, see the L<unpin|App::Pinto::Command::unpin> command.
-
-When pinning, all its sister packages in that distribution also become 
-pinned.  Pinned packages also cannot be unregistered from the stack
-or deleted from the repository without the C<--force> option.
+A package must be in the stack before you can pin it.  To bring a
+package into the stack, use the
+L<pull|App::Pinto::Command::pull> command.  To remove the pin
+from a package, please see the
+L<unpin|App::Pinto::Command::unpin> command.
 
 =head1 COMMAND ARGUMENTS
 
@@ -82,6 +79,10 @@ specified as packages or distributions, such as:
   AUTHOR/Some-Dist-1.2.tar.gz
   AUTHOR/Some-Other-Dist-1.3.zip
 
+When pinning a distribution, all the packages in that distribution
+become pinned.  Likewise when pinning a package, all its sister
+packages in the same distributon also become pinned.
+
 You can also pipe arguments to this command over STDIN.  In that case,
 blank lines and lines that look like comments (i.e. starting with "#"
 or ';') will be ignored.
@@ -90,23 +91,11 @@ or ';') will be ignored.
 
 =over 4
 
-=item --dry-run
+=item --dryrun
 
 Go through all the motions, but do not actually commit any changes to
-the repository.  Use this option to see how the command would
-potentially impact the stack.
-
-=item --message=TEXT
-
-=item -m TEXT
-
-Use TEXT as the revision history log message.  If you do not use the
-C<--message> option or the C<--use-default-message> option, then you
-will be prompted to enter the message via your text editor.  Use the
-C<EDITOR> or C<VISUAL> environment variables to control which editor
-is used.  A log message is not required whenever the C<--dry-run>
-option is set, or if the action did not yield any changes to the
-repository.
+the repository.  Use this option to see how operations would potentially
+impact the stack.
 
 =item --stack=NAME
 
@@ -115,20 +104,11 @@ name of whichever stack is currently marked as the default stack.  Use
 the L<stacks|App::Pinto::Command::stacks> command to see the
 stacks in the repository.
 
-=item --use-default-message
-
-=item -M
-
-Use the default value for the revision history log message.  Pinto
-will generate a semi-informative log message just based on the command
-and its arguments.  If you set an explicit message with C<--message>,
-the C<--use-default-message> option will be silently ignored.
-
 =back
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -138,3 +118,8 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
+
