@@ -1,19 +1,17 @@
-# ABSTRACT: show available stacks
-
 package App::Pinto::Command::stacks;
 
+# ABSTRACT: show available stacks
+
 use strict;
 use warnings;
 
-use Pinto::Util qw(interpolate);
-
 #-----------------------------------------------------------------------------
 
 use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -21,7 +19,7 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'format=s' => 'Format of the listing (See POD for details)' ],
+        [ 'format=s' => 'Format of the listing' ],
     );
 }
 
@@ -33,8 +31,8 @@ sub validate_args {
     $self->usage_error('No arguments are allowed')
         if @{ $args };
 
-    $opts->{format} = interpolate( $opts->{format} )
-        if exists $opts->{format};
+    $opts->{format} = eval qq{"$opts->{format}"} ## no critic qw(StringyEval)
+        if $opts->{format};
 
     return 1;
 }
@@ -42,11 +40,11 @@ sub validate_args {
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -54,16 +52,17 @@ App::Pinto::Command::stacks - show available stacks
 
 =head1 VERSION
 
-version 0.065_04
+version 0.041
 
 =head1 SYNOPSIS
 
   pinto --root=REPOSITORY_ROOT stacks [OPTIONS]
+  pinto --root=REPOSITORY_ROOT stacks [OPTIONS]
 
 =head1 DESCRIPTION
 
 This command lists the names (and some other details) of all the
-stacks currently available in the repository.
+stacks available in the repository.
 
 =head1 COMMAND ARGUMENTS
 
@@ -82,22 +81,16 @@ Valid placeholders are:
   -----------------------------------------------------------------------------
   %k             Stack name
   %e             Stack description
-  %M             Stack default status                             (*) = default
-  %L             Stack lock status                                (!) = locked
-  %i             Stack head revision id prefix
-  $I             Stack head revision id
-  %g             Stack head revision message (full)
-  %t             Stack head revision message title
-  %b             Stack head revision message body
-  %u             Stack head revision committed-on
-  %j             Stack head revision committed-by
+  %M             Stack default status                               (*) = default
+  %U             Stack last-modified-on
+  %j             Stack last-modified-by
   %%             A literal '%'
 
 =back
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -107,3 +100,7 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
