@@ -1,7 +1,7 @@
-# ABSTRACT: report statistics about the repository
-
 package App::Pinto::Command::statistics;
 
+# ABSTRACT: report statistics about the repository
+
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -20,11 +20,11 @@ sub command_names { return qw( statistics stats ) }
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -32,7 +32,7 @@ App::Pinto::Command::statistics - report statistics about the repository
 
 =head1 VERSION
 
-version 0.065_04
+version 0.041
 
 =head1 SYNOPSIS
 
@@ -40,9 +40,8 @@ version 0.065_04
 
 =head1 DESCRIPTION
 
-!! THIS COMMAND IS EXPERIMENTAL !!
-
-This command reports some statistics about the repository.
+This command reports some statistics about the repository.  It is
+currently only reports information about the default stack.
 
 =head1 COMMAND ARGUMENTS
 
@@ -54,7 +53,7 @@ None.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -64,3 +63,7 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
